DiskSpace class

Constructors

DiskSpace(num? freeSpace, num? totalSpace)
DiskSpace.fromMap(Map<String, dynamic> map)
factory

Properties

freeSpace → num?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSpace → num?
final
usedSpace → num?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited